==> mupad-1.4.2.tgz: mupad/share/mmg/include/kernel/MDM_pmod.h <==
/* $Date: 1995/07/21 09:33:44 $  $Author: andi $  $Revision: 1.2 $ */

/******************************************************************************/
/* DATEI:       MDM_pmod.h                                                    */
/* AUTOR:       Andreas Sorgatz                                               */
/* ERSTELLT:    25/04/94                                                      */
/* GEAENDERT:   16/05/94                                                      */
/* INHALT:      Enthaelt die Eintraege der Pseudomodul-Tabelle.               */
/*                                                                            */
/* Die Datei enthaelt Namen und Verwaltungsinformationen  der zum MuPAD-Kern  */
/* (statisch) gelinkten Pseudomodule.  Dazu gehoert die Deklaration der ver-  */
/* schiedenen Modul-Initialisierungsfunktionen und die AUFSTEIGEND SORTIERTE  */
/* Tabelle von Moduleintraegen der folgenden Art:                             */
/*                                                                            */
/*          { "<Modulname>", <Modulinitialisierungsfunktion> },               */
/*                                                                            */
/* wobei genau der letzte Tabelleneintrag den Wert:                           */
/*                                                                            */
/*          { NULL, NULL }                                                    */
/*                                                                            */
/* hat. Diese Datei wird entweder von Hand, besser aber mit dem Shell-script  */
/* 'mkmod' im Unterverzeichnis 'MODULE' erstellt. Weitere Informationen sind  */
/* dort in der Datei README zu finden.                                        */
/*                                                                            */
/******************************************************************************/

#ifndef __MDM_pmod__
#define __MDM_pmod__


/*** Deklaration aller Initialisierungsfunktionen von Pseudomodulen ***********/

/*** {NULL,NULL}-terminierte, aufsteigend sortierte Liste der Pseudomodule ****/

MDM_pmod_t MDMV_pmod[] = {

		{ NULL, NULL }
};

#endif /* __MDM_pmod__ */

==> mupad-2.0.0.tgz: mupad/share/mmg/include/kernel/MDM_pmod.h <==
/* $Date: 1999/06/02 07:21:11 $  $Author: kg $  $Revision: 1.3 $ */

/******************************************************************************/
/* DATEI:       MDM_pmod.h                                                    */
/* AUTOR:       Andreas Sorgatz                                               */
/* ERSTELLT:    25/04/94                                                      */
/* GEAENDERT:   16/05/94                                                      */
/* INHALT:      Enthaelt die Eintraege der Pseudomodul-Tabelle.               */
/*                                                                            */
/* Die Datei enthaelt Namen und Verwaltungsinformationen  der zum MuPAD-Kern  */
/* (statisch) gelinkten Pseudomodule.  Dazu gehoert die Deklaration der ver-  */
/* schiedenen Modul-Initialisierungsfunktionen und die AUFSTEIGEND SORTIERTE  */
/* Tabelle von Moduleintraegen der folgenden Art:                             */
/*                                                                            */
/*          { "<Modulname>", <Modulinitialisierungsfunktion> },               */
/*                                                                            */
/* wobei genau der letzte Tabelleneintrag den Wert:                           */
/*                                                                            */
/*          { NULL, NULL }                                                    */
/*                                                                            */
/* hat. Diese Datei wird entweder von Hand, besser aber mit dem Shell-script  */
/* 'mkmod' im Unterverzeichnis 'MODULE' erstellt. Weitere Informationen sind  */
/* dort in der Datei README zu finden.                                        */
/*                                                                            */
/******************************************************************************/

#ifndef __MDM_pmod__
#define __MDM_pmod__


/* Deklaration aller Initialisierungsfunktionen von Pseudomodulen ***********/

/* {NULL,NULL}-terminierte, aufsteigend sortierte Liste der Pseudomodule ****/

MDM_pmod_t MDMV_pmod[] = {

		{ NULL, NULL }
};

#endif /* __MDM_pmod__ */
